import { k as CreateCategoryRequest$1, l as CreateCategoryResponse$1, m as BulkCreateCategoryRequest$1, B as BulkCreateCategoryResponse$1, p as UpdateCategoryRequest$1, q as UpdateCategoryResponse$1, D as DeleteCategoryRequest$1, r as DeleteCategoryResponse$1, s as QueryCategoriesRequest$1, w as QueryCategoriesResponse$1, z as AssignEventsRequest$1, E as AssignEventsResponse$1, F as BulkAssignEventsRequest$1, c as BulkAssignEventsResponse$1, G as BulkAssignEventsAsyncRequest$1, H as BulkAssignEventsAsyncResponse$1, J as UnassignEventsRequest$1, K as UnassignEventsResponse$1, M as BulkUnassignEventsRequest$1, f as BulkUnassignEventsResponse$1, N as BulkUnassignEventsAsyncRequest$1, O as BulkUnassignEventsAsyncResponse$1, T as ListEventCategoriesRequest$1, L as ListEventCategoriesResponse$1, V as ReorderCategoryEventsRequest$1, Y as ReorderCategoryEventsResponse$1 } from './events-v1-category-categories.universal-C1gJTmtZ.js';

interface Category {
    /**
     * Category ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /**
     * Category name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /**
     * Date and time when category was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * The total number of draft and published events assigned to the category.
     * @readonly
     */
    counts?: CategoryCounts;
    /**
     * Category state. Possible values:
     *
     * `MANUAL`: Category is created manually by the user.
     * `AUTO`: Category is created automatically.
     * `RECURRING_EVENT`: Category is created automatically when publishing recurring events.
     * `HIDDEN`: Category can't be seen.
     *
     * Default: `MANUAL`.
     *
     * **Note:** The WIX_EVENTS.MANAGE_AUTO_CATEGORIES permission scope is required to use states other than `MANUAL`.
     * @maxSize 3
     */
    states?: StateWithLiterals[];
}
interface CategoryCounts {
    /** Total number of draft events assigned to the category. */
    assignedEventsCount?: number | null;
    /** Total number of published events assigned to the category. Deleted events are excluded. */
    assignedDraftEventsCount?: number | null;
}
declare enum State {
    /** Created manually by the user. */
    MANUAL = "MANUAL",
    /** Created automatically. */
    AUTO = "AUTO",
    /** Created when publishing recurring events. */
    RECURRING_EVENT = "RECURRING_EVENT",
    /** Category is hidden. */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type StateWithLiterals = State | 'MANUAL' | 'AUTO' | 'RECURRING_EVENT' | 'HIDDEN';
interface CreateCategoryRequest {
    /** Category to create. */
    category: Category;
}
interface CreateCategoryResponse {
    /** Created category. */
    category?: Category;
}
interface BulkCreateCategoryRequest {
    /**
     * Categories to create.
     * @minSize 1
     * @maxSize 10
     */
    categories: Category[];
}
interface BulkCreateCategoryResponse {
    /** Bulk create results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkCategoryResult {
    /** Metadata. */
    itemMetadata?: ItemMetadata;
    /** Category. */
    item?: Category;
}
interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
interface UpdateCategoryRequest {
    /** Category to update. */
    category: Category;
}
interface UpdateCategoryResponse {
    /** Updated category. */
    category?: Category;
}
interface DeleteCategoryRequest {
    /**
     * ID of category to be deleted.
     * @format GUID
     */
    categoryId: string;
}
interface DeleteCategoryResponse {
}
interface QueryCategoriesRequest {
    /** Options to use when querying categories. See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more details. */
    query: QueryV2;
    /**
     * Predefined sets of fields to return.
     * - `COUNTS`: Returns `assignedEventsCount`.
     * @maxSize 1
     */
    fieldset?: CategoryFieldsetWithLiterals[];
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter?: Record<string, any> | null;
    /**
     * Sort object in the form [{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]
     * See [supported fields](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events).
     * @maxSize 20
     */
    sort?: Sorting[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /**
     * Pointer to page of results using offset.
     * See [Pagination](https://dev.wix.com/api/rest/getting-started/pagination).
     */
    paging?: Paging;
}
interface Sorting {
    /**
     * Name of the field to sort by
     * @maxLength 100
     */
    fieldName?: string;
    /** Sort order (ASC/DESC). Defaults to ASC */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /**
     * Number of items to load per page.
     * @max 1000
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
declare enum CategoryFieldset {
    /** Include `assignedEventsCount` in the response. */
    COUNTS = "COUNTS"
}
/** @enumType */
type CategoryFieldsetWithLiterals = CategoryFieldset | 'COUNTS';
interface QueryCategoriesResponse {
    /** List of categories. */
    categories?: Category[];
    /** Metadata for the paginated results. */
    metaData?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface AssignEventsRequest {
    /**
     * ID of category to which events should be assigned.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
interface AssignEventsResponse {
}
interface BulkAssignEventsRequest {
    /**
     * A list of category IDs to which events should be assigned.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId: string[];
}
interface BulkAssignEventsResponse {
    /** Bulk assign results. */
    results?: BulkCategoryResult[];
    /** Metadata of results. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkAssignEventsAsyncRequest {
    /**
     * Category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter: Record<string, any> | null;
}
interface BulkAssignEventsAsyncResponse {
}
interface UnassignEventsRequest {
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 100
     */
    eventId: string[];
}
interface UnassignEventsResponse {
}
interface BulkUnassignEventsRequest {
    /**
     * A list of category IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /**
     * A list of events IDs.
     * @format GUID
     * @minSize 1
     * @maxSize 1
     */
    eventId?: string[];
}
interface BulkUnassignEventsResponse {
    /** Results. */
    results?: BulkCategoryResult[];
    /** Metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkUnassignEventsAsyncRequest {
    /**
     * Category ID.
     * @format GUID
     * @minSize 1
     * @maxSize 10
     */
    categoryId: string[];
    /** Filter. See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort#wix-events_wix-events_filter-and-sort_list-query-events). */
    filter: Record<string, any> | null;
}
interface BulkUnassignEventsAsyncResponse {
}
interface ListEventCategoriesRequest {
    /**
     * Event ID.
     * @format GUID
     */
    eventId: string;
}
interface ListEventCategoriesResponse {
    /** A list of categories. */
    categories?: Category[];
}
interface ReorderCategoryEventsRequest extends ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
    /**
     * Category ID.
     * @format GUID
     */
    categoryId: string;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string;
}
/** @oneof */
interface ReorderCategoryEventsRequestReferenceEventOneOf {
    /**
     * Move the event before defined `eventId`.
     * @format GUID
     */
    beforeEventId?: string;
    /**
     * Move the event after defined `eventId`.
     * @format GUID
     */
    afterEventId?: string;
}
interface ReorderCategoryEventsResponse {
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createCategory(): __PublicMethodMetaInfo<'POST', {}, CreateCategoryRequest$1, CreateCategoryRequest, CreateCategoryResponse$1, CreateCategoryResponse>;
declare function bulkCreateCategory(): __PublicMethodMetaInfo<'POST', {}, BulkCreateCategoryRequest$1, BulkCreateCategoryRequest, BulkCreateCategoryResponse$1, BulkCreateCategoryResponse>;
declare function updateCategory(): __PublicMethodMetaInfo<'PATCH', {
    categoryId: string;
}, UpdateCategoryRequest$1, UpdateCategoryRequest, UpdateCategoryResponse$1, UpdateCategoryResponse>;
declare function deleteCategory(): __PublicMethodMetaInfo<'DELETE', {
    categoryId: string;
}, DeleteCategoryRequest$1, DeleteCategoryRequest, DeleteCategoryResponse$1, DeleteCategoryResponse>;
declare function queryCategories(): __PublicMethodMetaInfo<'POST', {}, QueryCategoriesRequest$1, QueryCategoriesRequest, QueryCategoriesResponse$1, QueryCategoriesResponse>;
declare function assignEvents(): __PublicMethodMetaInfo<'POST', {
    categoryId: string;
}, AssignEventsRequest$1, AssignEventsRequest, AssignEventsResponse$1, AssignEventsResponse>;
declare function bulkAssignEvents(): __PublicMethodMetaInfo<'POST', {}, BulkAssignEventsRequest$1, BulkAssignEventsRequest, BulkAssignEventsResponse$1, BulkAssignEventsResponse>;
declare function bulkAssignEventsAsync(): __PublicMethodMetaInfo<'POST', {}, BulkAssignEventsAsyncRequest$1, BulkAssignEventsAsyncRequest, BulkAssignEventsAsyncResponse$1, BulkAssignEventsAsyncResponse>;
declare function unassignEvents(): __PublicMethodMetaInfo<'DELETE', {
    categoryId: string;
}, UnassignEventsRequest$1, UnassignEventsRequest, UnassignEventsResponse$1, UnassignEventsResponse>;
declare function bulkUnassignEvents(): __PublicMethodMetaInfo<'DELETE', {}, BulkUnassignEventsRequest$1, BulkUnassignEventsRequest, BulkUnassignEventsResponse$1, BulkUnassignEventsResponse>;
declare function bulkUnassignEventsAsync(): __PublicMethodMetaInfo<'POST', {}, BulkUnassignEventsAsyncRequest$1, BulkUnassignEventsAsyncRequest, BulkUnassignEventsAsyncResponse$1, BulkUnassignEventsAsyncResponse>;
declare function listEventCategories(): __PublicMethodMetaInfo<'GET', {
    eventId: string;
}, ListEventCategoriesRequest$1, ListEventCategoriesRequest, ListEventCategoriesResponse$1, ListEventCategoriesResponse>;
declare function reorderCategoryEvents(): __PublicMethodMetaInfo<'POST', {
    categoryId: string;
}, ReorderCategoryEventsRequest$1, ReorderCategoryEventsRequest, ReorderCategoryEventsResponse$1, ReorderCategoryEventsResponse>;

export { type __PublicMethodMetaInfo, assignEvents, bulkAssignEvents, bulkAssignEventsAsync, bulkCreateCategory, bulkUnassignEvents, bulkUnassignEventsAsync, createCategory, deleteCategory, listEventCategories, queryCategories, reorderCategoryEvents, unassignEvents, updateCategory };
