import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { C as Category, B as BulkCreateCategoryResponse, U as UpdateCategory, Q as QueryCategoriesOptions, a as CategoriesQueryBuilder, b as BulkAssignEventsOptions, c as BulkAssignEventsResponse, d as BulkAssignEventsAsyncOptions, e as BulkUnassignEventsOptions, f as BulkUnassignEventsResponse, g as BulkUnassignEventsAsyncOptions, L as ListEventCategoriesResponse, R as ReorderCategoryEventsOptions } from './events-v1-category-categories.universal-C1gJTmtZ.js';
export { a3 as ActionEvent, A as ApplicationError, z as AssignEventsRequest, E as AssignEventsResponse, o as BulkActionMetadata, G as BulkAssignEventsAsyncRequest, H as BulkAssignEventsAsyncResponse, F as BulkAssignEventsRequest, n as BulkCategoryResult, m as BulkCreateCategoryRequest, N as BulkUnassignEventsAsyncRequest, O as BulkUnassignEventsAsyncResponse, M as BulkUnassignEventsRequest, a7 as CategoriesQueryResult, j as CategoryCounts, i as CategoryFieldset, k as CreateCategoryRequest, l as CreateCategoryResponse, y as Cursors, D as DeleteCategoryRequest, r as DeleteCategoryResponse, Z as DomainEvent, _ as DomainEventBodyOneOf, $ as EntityCreatedEvent, a2 as EntityDeletedEvent, a1 as EntityUpdatedEvent, a5 as IdentificationData, a6 as IdentificationDataIdOneOf, I as ItemMetadata, T as ListEventCategoriesRequest, a4 as MessageEnvelope, P as Paging, x as PagingMetadataV2, s as QueryCategoriesRequest, w as QueryCategoriesResponse, t as QueryV2, u as QueryV2PagingMethodOneOf, a8 as ReorderCategoryEventsOptionsReferenceEventOneOf, V as ReorderCategoryEventsRequest, X as ReorderCategoryEventsRequestReferenceEventOneOf, Y as ReorderCategoryEventsResponse, a0 as RestoreInfo, h as SortOrder, v as Sorting, S as State, J as UnassignEventsRequest, K as UnassignEventsResponse, p as UpdateCategoryRequest, q as UpdateCategoryResponse, W as WebhookIdentityType } from './events-v1-category-categories.universal-C1gJTmtZ.js';

declare function createCategory$1(httpClient: HttpClient): CreateCategorySignature;
interface CreateCategorySignature {
    /**
     * Creates a category.
     * @param - Category to create.
     * @returns Created category.
     */
    (category: Category): Promise<Category>;
}
declare function bulkCreateCategory$1(httpClient: HttpClient): BulkCreateCategorySignature;
interface BulkCreateCategorySignature {
    /**
     * Creates multiple categories at once.
     * @param - Categories to create.
     */
    (categories: Category[]): Promise<BulkCreateCategoryResponse>;
}
declare function updateCategory$1(httpClient: HttpClient): UpdateCategorySignature;
interface UpdateCategorySignature {
    /**
     * Updates an existing category.
     * @param - Category ID.
     * @returns Updated category.
     */
    (_id: string, category: UpdateCategory): Promise<Category>;
}
declare function deleteCategory$1(httpClient: HttpClient): DeleteCategorySignature;
interface DeleteCategorySignature {
    /**
     * Deletes a category.
     * @param - ID of category to be deleted.
     */
    (categoryId: string): Promise<void>;
}
declare function queryCategories$1(httpClient: HttpClient): QueryCategoriesSignature;
interface QueryCategoriesSignature {
    /**
     * Creates a query to retrieve a list of categories.
     *
     *
     * The `queryCategories()` function builds a query to retrieve a list of categories and returns a `CategoriesQueryBuilder` object.
     *
     * The returned object contains the query definition, which is typically used to run the query using the [`find()`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/find) function.
     *
     * You can refine the query by chaining `CategoriesQueryBuilder` functions onto the query. `CategoriesQueryBuilder` functions enable you to sort, filter, and control the results `queryCategories()` returns.
     *
     * `queryCategories()` runs with these `CategoriesQueryBuilder` defaults, which you can override:
     *
     *  - [`limit(50)`](https://www.wix.com/velo/reference/wix-events-v2/categories/categoriesquerybuilder/limit)
     * @param - Options to use when querying categories.
     */
    (options?: QueryCategoriesOptions | undefined): CategoriesQueryBuilder;
}
declare function assignEvents$1(httpClient: HttpClient): AssignEventsSignature;
interface AssignEventsSignature {
    /**
     * Assigns events to a single category.
     * @param - ID of category to which events should be assigned.
     * @param - A list of events IDs.
     */
    (categoryId: string, eventId: string[]): Promise<void>;
}
declare function bulkAssignEvents$1(httpClient: HttpClient): BulkAssignEventsSignature;
interface BulkAssignEventsSignature {
    /**
     * Assigns events to multiple categories at once.
     * @param - A list of category IDs to which events should be assigned.
     * @param - Options to use when assigning events to multiple categories.
     */
    (categoryId: string[], options: BulkAssignEventsOptions): Promise<BulkAssignEventsResponse>;
}
declare function bulkAssignEventsAsync$1(httpClient: HttpClient): BulkAssignEventsAsyncSignature;
interface BulkAssignEventsAsyncSignature {
    /**
     * Assigns events that match given filter criteria to multiple categories.
     *
     * Unlike the [`bulkAssignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkassignevents) function, this function can handle numerous requests and is less prone to failures.
     *
     * However, the events will not be instantly assigned to the categories (as with `bulkAssignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
     * @param - Category IDs.
     * @param - Options to use when assigning events to multiple categories.
     */
    (categoryId: string[], options: BulkAssignEventsAsyncOptions): Promise<void>;
}
declare function unassignEvents$1(httpClient: HttpClient): UnassignEventsSignature;
interface UnassignEventsSignature {
    /**
     * Unassigns events from a category.
     * @param - Category ID.
     * @param - A list of events IDs.
     */
    (categoryId: string, eventId: string[]): Promise<void>;
}
declare function bulkUnassignEvents$1(httpClient: HttpClient): BulkUnassignEventsSignature;
interface BulkUnassignEventsSignature {
    /**
     * Unassigns events from multiple categories at once.
     * @param - A list of category IDs.
     * @param - Options to use when removing events from multiple categories.
     */
    (categoryId: string[], options?: BulkUnassignEventsOptions | undefined): Promise<BulkUnassignEventsResponse>;
}
declare function bulkUnassignEventsAsync$1(httpClient: HttpClient): BulkUnassignEventsAsyncSignature;
interface BulkUnassignEventsAsyncSignature {
    /**
     * Removes events that match given filter criteria from multiple categories.
     *
     * Unlike the [`bulkUnassignEvents()`](https://www.wix.com/velo/reference/wix-events-v2/categories/bulkunassignevents) function, this function can handle numerous requests and is less prone to failures.
     *
     * However, the events will not be instantly removed from the categories (as with `bulkUnassignEvents()`), but rather after some time. In this case, if try to [`listEventCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/listeventcategories) or [`queryCategories`](https://www.wix.com/velo/reference/wix-events-v2/categories/querycategories), you might not get the correct response.
     * @param - Category ID.
     * @param - Options to use when removing events from multiple categories.
     */
    (categoryId: string[], options: BulkUnassignEventsAsyncOptions): Promise<void>;
}
declare function listEventCategories$1(httpClient: HttpClient): ListEventCategoriesSignature;
interface ListEventCategoriesSignature {
    /**
     * Retrieves a list of categories that are not in the `HIDDEN` state.
     * @param - Event ID.
     */
    (eventId: string): Promise<ListEventCategoriesResponse>;
}
declare function reorderCategoryEvents$1(httpClient: HttpClient): ReorderCategoryEventsSignature;
interface ReorderCategoryEventsSignature {
    /**
     * Change the order of events that are assigned to the same category on the Events Widget.
     *
     *
     * For more information see [this article](https://support.wix.com/en/article/creating-and-displaying-event-categories)
     * @param - Category ID.
     * @param - Options to use when reordering events.
     */
    (categoryId: string, options?: ReorderCategoryEventsOptions | undefined): Promise<void>;
}

declare const createCategory: MaybeContext<BuildRESTFunction<typeof createCategory$1> & typeof createCategory$1>;
declare const bulkCreateCategory: MaybeContext<BuildRESTFunction<typeof bulkCreateCategory$1> & typeof bulkCreateCategory$1>;
declare const updateCategory: MaybeContext<BuildRESTFunction<typeof updateCategory$1> & typeof updateCategory$1>;
declare const deleteCategory: MaybeContext<BuildRESTFunction<typeof deleteCategory$1> & typeof deleteCategory$1>;
declare const queryCategories: MaybeContext<BuildRESTFunction<typeof queryCategories$1> & typeof queryCategories$1>;
declare const assignEvents: MaybeContext<BuildRESTFunction<typeof assignEvents$1> & typeof assignEvents$1>;
declare const bulkAssignEvents: MaybeContext<BuildRESTFunction<typeof bulkAssignEvents$1> & typeof bulkAssignEvents$1>;
declare const bulkAssignEventsAsync: MaybeContext<BuildRESTFunction<typeof bulkAssignEventsAsync$1> & typeof bulkAssignEventsAsync$1>;
declare const unassignEvents: MaybeContext<BuildRESTFunction<typeof unassignEvents$1> & typeof unassignEvents$1>;
declare const bulkUnassignEvents: MaybeContext<BuildRESTFunction<typeof bulkUnassignEvents$1> & typeof bulkUnassignEvents$1>;
declare const bulkUnassignEventsAsync: MaybeContext<BuildRESTFunction<typeof bulkUnassignEventsAsync$1> & typeof bulkUnassignEventsAsync$1>;
declare const listEventCategories: MaybeContext<BuildRESTFunction<typeof listEventCategories$1> & typeof listEventCategories$1>;
declare const reorderCategoryEvents: MaybeContext<BuildRESTFunction<typeof reorderCategoryEvents$1> & typeof reorderCategoryEvents$1>;

export { BulkAssignEventsAsyncOptions, BulkAssignEventsOptions, BulkAssignEventsResponse, BulkCreateCategoryResponse, BulkUnassignEventsAsyncOptions, BulkUnassignEventsOptions, BulkUnassignEventsResponse, CategoriesQueryBuilder, Category, ListEventCategoriesResponse, QueryCategoriesOptions, ReorderCategoryEventsOptions, UpdateCategory, assignEvents, bulkAssignEvents, bulkAssignEventsAsync, bulkCreateCategory, bulkUnassignEvents, bulkUnassignEventsAsync, createCategory, deleteCategory, listEventCategories, queryCategories, reorderCategoryEvents, unassignEvents, updateCategory };
